==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/SampleFile.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Produces a file with the given contents but only once, if the file doesn't already exist.
 * <p>
 * Use this for creating example code files or other resources.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.437Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.SampleFile")
public class SampleFile extends io.github.cdklabs.projen.Component {

    protected SampleFile(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SampleFile(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (experimental) Creates a new SampleFile object.
     * <p>
     * @param project - the project to tie this file to. This parameter is required.
     * @param filePath - the relative path in the project to put the file. This parameter is required.
     * @param options - the options for the file. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SampleFile(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull java.lang.String filePath, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.SampleFileOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(filePath, "filePath is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Synthesizes files to the project output directory.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void synthesize() {
        software.amazon.jsii.Kernel.call(this, "synthesize", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.SampleFile}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.SampleFile> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project - the project to tie this file to. This parameter is required.
         * @param filePath - the relative path in the project to put the file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            return new Builder(project, filePath);
        }

        private final io.github.cdklabs.projen.Project project;
        private final java.lang.String filePath;
        private final io.github.cdklabs.projen.SampleFileOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            this.project = project;
            this.filePath = filePath;
            this.options = new io.github.cdklabs.projen.SampleFileOptions.Builder();
        }

        /**
         * (experimental) The contents of the file to write.
         * <p>
         * @return {@code this}
         * @param contents The contents of the file to write. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder contents(final java.lang.String contents) {
            this.options.contents(contents);
            return this;
        }

        /**
         * (experimental) Absolute path to a file to copy the contents from (does not need to be a text file).
         * <p>
         * If your project is Typescript-based and has configured <code>testdir</code> to be a
         * subdirectory of <code>src</code>, sample files should outside of the <code>src</code> directory,
         * otherwise they may not be copied. For example:
         * <p>
         * <blockquote><pre>
         * new SampleFile(this, 'assets/icon.png', { source: path.join(__dirname, '..', 'sample-assets', 'icon.png') });
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param sourcePath Absolute path to a file to copy the contents from (does not need to be a text file). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder sourcePath(final java.lang.String sourcePath) {
            this.options.sourcePath(sourcePath);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.SampleFile}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.SampleFile build() {
            return new io.github.cdklabs.projen.SampleFile(
                this.project,
                this.filePath,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/SampleFile.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Produces a file with the given contents but only once, if the file doesn't already exist.
 * <p>
 * Use this for creating example code files or other resources.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.146Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.SampleFile")
public class SampleFile extends io.github.cdklabs.projen.Component {

    protected SampleFile(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SampleFile(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (experimental) Creates a new SampleFile object.
     * <p>
     * @param project <ul><li>the project to tie this file to.</li></ul> This parameter is required.
     * @param filePath <ul><li>the relative path in the project to put the file.</li></ul> This parameter is required.
     * @param options <ul><li>the options for the file.</li></ul> This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SampleFile(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull java.lang.String filePath, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.SampleFileOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(filePath, "filePath is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Synthesizes files to the project output directory.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void synthesize() {
        software.amazon.jsii.Kernel.call(this, "synthesize", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.SampleFile}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.SampleFile> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project <ul><li>the project to tie this file to.</li></ul> This parameter is required.
         * @param filePath <ul><li>the relative path in the project to put the file.</li></ul> This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            return new Builder(project, filePath);
        }

        private final io.github.cdklabs.projen.Project project;
        private final java.lang.String filePath;
        private final io.github.cdklabs.projen.SampleFileOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            this.project = project;
            this.filePath = filePath;
            this.options = new io.github.cdklabs.projen.SampleFileOptions.Builder();
        }

        /**
         * (experimental) The contents of the file to write.
         * <p>
         * @return {@code this}
         * @param contents The contents of the file to write. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder contents(final java.lang.String contents) {
            this.options.contents(contents);
            return this;
        }

        /**
         * (experimental) Absolute path to a file to copy the contents from (does not need to be a text file).
         * <p>
         * If your project is Typescript-based and has configured <code>testdir</code> to be a
         * subdirectory of <code>src</code>, sample files should outside of the <code>src</code> directory,
         * otherwise they may not be copied. For example:
         * <p>
         * <blockquote><pre>
         * new SampleFile(this, 'assets/icon.png', { source: path.join(__dirname, '..', 'sample-assets', 'icon.png') });
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param sourcePath Absolute path to a file to copy the contents from (does not need to be a text file). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder sourcePath(final java.lang.String sourcePath) {
            this.options.sourcePath(sourcePath);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.SampleFile}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.SampleFile build() {
            return new io.github.cdklabs.projen.SampleFile(
                this.project,
                this.filePath,
                this.options.build()
            );
        }
    }
}
